@@ -44,6 +44,17 @@ def datawatch_client_factory(auth: ApiAuthConf):
 
 class DatawatchClient(BaseApiClient, GeneratedDatawatchClient, ABC):
 
+    def delete_metrics(self, metrics: List[MetricConfiguration] = None):
+        """
+        Deletes multiple metrics.
+        Args:
+            metrics: List of metric configurations to delete.
+        Warnings: Will log a warning when attempting to delete a metric created by Bigconfig.
+        """
+
+        for m in metrics:
+            self.delete_metric(m)
+
     def get_table_level_metrics(self) -> MetricNamesResponse:
         url = '/api/v1/metrics/table-level-metric-names'
 
