@@ -18,7 +18,7 @@ log = get_logger(__file__)
 def _is_table_level_metric(metric_type: SimpleMetricType, table_level_metrics: List[SimplePredefinedMetricName]) -> bool:
     if not isinstance(metric_type, SimplePredefinedMetric):
         return False
-    if metric_type.metric in table_level_metrics:
+    if metric_type.predefined_metric in table_level_metrics:
         return True
 
     return False
@@ -354,10 +354,6 @@ def get_time_interval_for_delay_string(delay_at_update: str, metric_type: str, u
     """
     split_input = delay_at_update.split(" ")
     interval_value = int(split_input[0])
-    if interval_value == 0:
-        """Returns None if interval value is 0 -- default.  This works to remove the TimeInterval from the final created
-        object so that default is used at the service."""
-        return None
     interval_type = get_proto_interval_type(split_input[1])
     if metric_type == "HOURS_SINCE_MAX_DATE":
         hours_from_cron = get_max_hours_from_cron(update_schedule)
