@@ -1,16 +1,13 @@
 from __future__ import annotations
 
-import enum
 import re
-import sys
 from abc import ABC
-from collections.abc import Iterable
-from typing import List, Optional, TypeVar, Union, Any
+from typing import List, Optional, TypeVar, Union
 
 import betterproto
 import yaml
 from pydantic import validator, Field, root_validator
-from pydantic_yaml import YamlIntEnum, YamlStrEnum
+from pydantic_yaml import YamlStrEnum
 
 from bigeye_sdk.bigconfig_validation.validation_functions import safe_split_dict_entry_lines, must_be_list_validator
 from bigeye_sdk.bigconfig_validation.yaml_model_base import YamlModelWithValidatorContext
@@ -48,7 +45,7 @@ class SimpleMetricType(PydanticSubtypeSerializable, DatawatchFacade, ABC):
         freshness_metric_names = [SimplePredefinedMetricName.HOURS_SINCE_LAST_LOAD,
                                   SimplePredefinedMetricName.HOURS_SINCE_MAX_DATE,
                                   SimplePredefinedMetricName.HOURS_SINCE_MAX_TIMESTAMP]
-        return [SimplePredefinedMetric(type="PREDEFINED", metric=i) for i in freshness_metric_names]
+        return [SimplePredefinedMetric(type="PREDEFINED", predefined_metric=i) for i in freshness_metric_names]
 
     @classmethod
     def from_datawatch_object(cls, obj: MetricType) -> SimpleMetricType:
@@ -65,7 +62,7 @@ class SimpleMetricType(PydanticSubtypeSerializable, DatawatchFacade, ABC):
         elif t == 'predefined_metric':
             return SimplePredefinedMetric(
                 type='PREDEFINED',
-                metric=SimplePredefinedMetricName.from_datawatch_object(obj.predefined_metric.metric_name)
+                predefined_metric=SimplePredefinedMetricName.from_datawatch_object(obj.predefined_metric.metric_name)
             )
         else:
             error_message = f"Metric type not supported: {t}"
@@ -73,9 +70,10 @@ class SimpleMetricType(PydanticSubtypeSerializable, DatawatchFacade, ABC):
 
 
 class SimplePredefinedMetric(SimpleMetricType, type='PREDEFINED'):
-    metric: SimplePredefinedMetricName
+    type = 'PREDEFINED'
+    predefined_metric: SimplePredefinedMetricName
 
-    @validator('metric', pre=True)
+    @validator('predefined_metric', pre=True)
     def must_be_valid_metric(cls, v):
         try:
             return SimplePredefinedMetricName(v)
@@ -104,10 +102,11 @@ class SimplePredefinedMetric(SimpleMetricType, type='PREDEFINED'):
             return SimplePredefinedMetricName.UNDEFINED
 
     def to_datawatch_object(self, **kwargs) -> MetricType:
-        return MetricType(predefined_metric=PredefinedMetric(metric_name=self.metric.to_datawatch_object()))
+        return MetricType(predefined_metric=PredefinedMetric(metric_name=self.predefined_metric.to_datawatch_object()))
 
 
 class SimpleTemplateMetric(SimpleMetricType, type='TEMPLATE'):
+    type = 'TEMPLATE'
     template_id: int
     aggregation_type: SimpleAggregationType
     template_name: Optional[str] = None
@@ -292,7 +291,7 @@ class SimpleAutoThreshold(SimpleThreshold, type='AUTO'):
 
 
 class SimpleConstantThreshold(SimpleThreshold, type='CONSTANT'):
-    upper_bound: Optional[float] = None
+    upper_bound: Optional[float] = 0
     lower_bound: Optional[float] = 0
 
     def to_datawatch_object(self) -> List[Threshold]:
@@ -301,21 +300,19 @@ class SimpleConstantThreshold(SimpleThreshold, type='CONSTANT'):
         :return: a List of Thresholds
         """
         thresholds: List[Threshold] = []
-        if self.lower_bound:
-            lb = SimpleBound(bound_type=SimpleBoundType.LOWER_BOUND_SIMPLE_BOUND_TYPE, value=self.lower_bound)
-            lbt = Threshold(constant_threshold=ConstantThreshold(bound=lb))
-            thresholds.append(lbt)
-        if self.upper_bound:
-            ub = SimpleBound(bound_type=SimpleBoundType.UPPER_BOUND_SIMPLE_BOUND_TYPE, value=self.upper_bound)
-            ubt = Threshold(constant_threshold=ConstantThreshold(bound=ub))
-            thresholds.append(ubt)
+        lb = SimpleBound(bound_type=SimpleBoundType.LOWER_BOUND_SIMPLE_BOUND_TYPE, value=self.lower_bound)
+        lbt = Threshold(constant_threshold=ConstantThreshold(bound=lb))
+        thresholds.append(lbt)
+        ub = SimpleBound(bound_type=SimpleBoundType.UPPER_BOUND_SIMPLE_BOUND_TYPE, value=self.upper_bound)
+        ubt = Threshold(constant_threshold=ConstantThreshold(bound=ub))
+        thresholds.append(ubt)
 
         return thresholds
 
 
 class SimpleFreshnessThreshold(SimpleThreshold, type='FRESHNESS'):
     cron: str
-    upper_bound: float
+    upper_bound: float = 0
     timezone: Optional[str] = None
     delay_at_update: Optional[SimpleTimeInterval] = SimpleTimeInterval(interval_type=SimpleTimeIntervalType.HOURS,
                                                                        interval_value=0)
@@ -332,42 +329,38 @@ class SimpleFreshnessThreshold(SimpleThreshold, type='FRESHNESS'):
 
 class SimpleRelativeThreshold(SimpleThreshold, type='RELATIVE'):
     lookback: SimpleTimeInterval
-    upper_bound: Optional[float] = None
+    upper_bound: Optional[float] = 0
     lower_bound: float = 0
 
     def to_datawatch_object(self, **kwargs) -> List[Threshold]:
         lkbk = self.lookback.to_datawatch_object()
 
         thresholds: List[Threshold] = []
-        if self.lower_bound:
-            lb = SimpleBound(bound_type=SimpleBoundType.LOWER_BOUND_SIMPLE_BOUND_TYPE, value=self.lower_bound)
-            lbt = Threshold(relative_threshold=RelativeThreshold(lookback=lkbk, bound=lb))
-            thresholds.append(lbt)
-        if self.upper_bound:
-            ub = SimpleBound(bound_type=SimpleBoundType.UPPER_BOUND_SIMPLE_BOUND_TYPE, value=self.upper_bound)
-            ubt = Threshold(relative_threshold=RelativeThreshold(lookback=lkbk, bound=ub))
-            thresholds.append(ubt)
+        lb = SimpleBound(bound_type=SimpleBoundType.LOWER_BOUND_SIMPLE_BOUND_TYPE, value=self.lower_bound)
+        lbt = Threshold(relative_threshold=RelativeThreshold(lookback=lkbk, bound=lb))
+        thresholds.append(lbt)
+        ub = SimpleBound(bound_type=SimpleBoundType.UPPER_BOUND_SIMPLE_BOUND_TYPE, value=self.upper_bound)
+        ubt = Threshold(relative_threshold=RelativeThreshold(lookback=lkbk, bound=ub))
+        thresholds.append(ubt)
 
         return thresholds
 
 
 class SimpleStdDevThreshold(SimpleThreshold, type='STDDEV'):
     lookback: SimpleTimeInterval
-    upper_bound: Optional[float] = None
+    upper_bound: Optional[float] = 0
     lower_bound: float = 0
 
     def to_datawatch_object(self, **kwargs) -> List[Threshold]:
         lkbk = self.lookback.to_datawatch_object()
 
         thresholds: List[Threshold] = []
-        if self.lower_bound:
-            lb = SimpleBound(bound_type=SimpleBoundType.LOWER_BOUND_SIMPLE_BOUND_TYPE, value=self.lower_bound)
-            lbt = Threshold(standard_deviation_threshold=StandardDeviationThreshold(lookback=lkbk, bound=lb))
-            thresholds.append(lbt)
-        if self.upper_bound:
-            ub = SimpleBound(bound_type=SimpleBoundType.UPPER_BOUND_SIMPLE_BOUND_TYPE, value=self.upper_bound)
-            ubt = Threshold(standard_deviation_threshold=StandardDeviationThreshold(lookback=lkbk, bound=ub))
-            thresholds.append(ubt)
+        lb = SimpleBound(bound_type=SimpleBoundType.LOWER_BOUND_SIMPLE_BOUND_TYPE, value=self.lower_bound)
+        lbt = Threshold(standard_deviation_threshold=StandardDeviationThreshold(lookback=lkbk, bound=lb))
+        thresholds.append(lbt)
+        ub = SimpleBound(bound_type=SimpleBoundType.UPPER_BOUND_SIMPLE_BOUND_TYPE, value=self.upper_bound)
+        ubt = Threshold(standard_deviation_threshold=StandardDeviationThreshold(lookback=lkbk, bound=ub))
+        thresholds.append(ubt)
 
         return thresholds
 
@@ -384,18 +377,19 @@ class SimpleNotificationChannel(PydanticSubtypeSerializable, DatawatchFacade, AB
         if not t:
             t = get_type_from_dict(obj)
         if t == 'email':
-            return EmailNotificationChannel(type='EMAIL', value=obj.email)
+            return EmailNotificationChannel(type='EMAIL', email=obj.email)
         elif t == 'slack_channel':
-            return SlackNotificationChannel(type='SLACK', value=obj.slack_channel)
+            return SlackNotificationChannel(type='SLACK', slack=obj.slack_channel)
         else:
             error_message = f"Notification channel type not supported: {t}"
             raise InvalidConfigurationException(error_message)
 
 
 class EmailNotificationChannel(SimpleNotificationChannel, type='EMAIL'):
-    value: str
+    type = 'EMAIL'
+    email: str
 
-    @validator('value')
+    @validator('email')
     def must_have_correct_email_format(cls, v):
         p = re.compile(r'([A-Za-z0-9]+[.-_+])*[A-Za-z0-9]+@[A-Za-z0-9-]+(\.[A-Z|a-z]{2,})+')
         if not re.fullmatch(p, v):
@@ -406,13 +400,14 @@ class EmailNotificationChannel(SimpleNotificationChannel, type='EMAIL'):
         return v
 
     def to_datawatch_object(self, **kwargs) -> NotificationChannel:
-        return NotificationChannel(email=self.value)
+        return NotificationChannel(email=self.email)
 
 
 class SlackNotificationChannel(SimpleNotificationChannel, type='SLACK'):
-    value: str
+    type = 'SLACK'
+    slack: str
 
-    @validator('value')
+    @validator('slack')
     def must_have_valid_channel_format(cls, v):
         p = re.compile(r'[#@]\S{1,20}')
         if not re.fullmatch(p, v):
@@ -423,7 +418,7 @@ class SlackNotificationChannel(SimpleNotificationChannel, type='SLACK'):
         return v
 
     def to_datawatch_object(self, **kwargs) -> NotificationChannel:
-        return NotificationChannel(slack_channel=self.value)
+        return NotificationChannel(slack_channel=self.slack)
 
 
 class SimpleMetricParameter(YamlModelWithValidatorContext, DatawatchFacade):
@@ -580,7 +575,7 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
 
     @validator('threshold', always=True, pre=False)
     def set_default_threshold(cls, threshold, values):
-        metric_type = values['metric_type']
+        metric_type = values.get('metric_type')
 
         if threshold:
             """For the case that a user has specifically defined a metric"""
@@ -608,7 +603,7 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
 
     @validator('schedule_frequency', always=True, pre=False)
     def set_default_schedule_frequency(cls, schedule_frequency, values):
-        metric_type = values['metric_type']
+        metric_type = values.get('metric_type')
 
         if schedule_frequency:
             """For the case that a user has specifically defined a metric"""
@@ -648,7 +643,7 @@ class SimpleMetricDefinition(YamlModelWithValidatorContext, DatawatchFacade):
             SimpleMetricDefinition.register_validation_error(
                 error_lines=[errlns],
                 error_message=FORMATTING_ERRMSG.format(
-                    s='Metric Type is an object.  Please include `type` and `metric` attributes')
+                    s='Metric Type is an object.')
             )
 
             return {'type': 'PREDEFINED', 'metric': 'UNDEFINED'}
